@@ -1,4 +1,3 @@
-# import mysql.connector as misql
 import mysql.connector
 import traceback
 import sys
@@ -9,11 +8,10 @@ from MySQLquerys.config import config
 
 
 class DbConnection:
-    def __init__(self, db_type='MySQL'):
-        self.iniFile = r"D:\Python\MySQL\SQL_Query\database.ini"
-        self.data_base_type = db_type
+    def __init__(self, ini_file):
+        self.iniFile = ini_file
         try:
-            params = config(filename=self.iniFile, section=db_type)
+            params = config(self.iniFile)
             self.connection = mysql.connector.connect(**params)
         except Exception as err:
             print(err)
@@ -45,7 +43,7 @@ class DbConnection:
 
     @active_data_base.setter
     def active_data_base(self, data_base_name):
-        self.dataBase = DataBase(self.data_base_type, data_base_name)
+        self.dataBase = DataBase(self.iniFile, data_base_name)
 
     def drop_data_base(self, schema_name):
         cursor = self.connection.cursor()
@@ -68,17 +66,11 @@ class DbConnection:
 
 
 class DataBase(DbConnection):
-    def __init__(self, db_type, data_base_name):
-        super().__init__(db_type)
+    def __init__(self, iniFile, data_base_name):
+        super().__init__(iniFile)
         self.connection.database = data_base_name
         self.data_base_name = data_base_name
 
-    def drop_table(self, tableName):
-        cursor = self.connection.cursor()
-        query = 'DROP TABLE {}'.format(tableName)
-        cursor.execute(query)
-        cursor.close
-
     @property
     def tables(self):
         cursor = self.connection.cursor()
@@ -96,7 +88,13 @@ class DataBase(DbConnection):
 
     @active_table.setter
     def active_table(self, table_name):
-        self.table = Table(self.data_base_type, self.data_base_name, table_name)
+        self.table = Table(self.iniFile, self.data_base_name, table_name)
+
+    def drop_table(self, tableName):
+        cursor = self.connection.cursor()
+        query = 'DROP TABLE {}'.format(tableName)
+        cursor.execute(query)
+        cursor.close
 
     def createTableFromFile(self, file):
         print(sys._getframe().f_code.co_name)
@@ -123,8 +121,8 @@ class DataBase(DbConnection):
 
 
 class Table(DataBase):
-    def __init__(self, db_type, data_base_name, table_name):
-        super().__init__(db_type, data_base_name)
+    def __init__(self, iniFile, data_base_name, table_name):
+        super().__init__(iniFile, data_base_name)
         self.table_name = table_name
 
     @property
@@ -489,20 +487,15 @@ class Table(DataBase):
             values.append(i)
         return values
 
-    # def unionTables(self):
-    #     query =
-
 
 if __name__ == '__main__':
     try:
-        db = DbConnection('MySQL')
+        iniFile = r"D:\Python\MySQL\SQL_Query\database.ini"
+        db = DbConnection(iniFile)
         print(db.version)
-
-        # dataBase = DataBase('MySQL', 'cheltuieli')
-        # print(dataBase.tables)
-
-        table = Table('MySQL', 'cheltuieli', 'real_expenses')
-        table = Table('MySQL', 'myfolderstructure', 'apartament')
-
+        db = DataBase(iniFile, 'myfolderstructure')
+        print(db.tables)
+        table = Table(iniFile, 'myfolderstructure', 'apartament')
+        print(table.columnsNames)
     except Exception as error:
         print(error)
